@@ -737,7 +737,7 @@
               as.integer(beta.size),
               as.integer(beta.size),
               as.integer(n),
-              res = xix)$res
+              res = xix, PACKAGE = "geoR")$res
     attr(xix, "dim") <- c(beta.size, beta.size)
     if(length(as.vector(xix)) == 1) {
       ixix <- 1/xix
@@ -757,7 +757,7 @@
               as.integer(beta.size),
               as.integer(1),
               as.integer(n),
-              res = xiy)$res
+              res = xiy, PACKAGE = "geoR")$res
     beta.hat <- as.vector(ixix %*% xiy)
     yiy <- as.double(0.0)
     yiy <- .C("bilinearform_XAY",
@@ -768,7 +768,7 @@
               as.integer(1),
               as.integer(1),
               as.integer(n),
-              res = yiy)$res
+              res = yiy, PACKAGE = "geoR")$res
     ssresmat <- as.vector(yiy - crossprod(beta.hat,xiy))
     if(.temp.list$method == "ML") {
       neglik <- ((n/2) * log(2 * pi) +
@@ -924,7 +924,7 @@ function(lambda)
               as.integer(beta.size),
               as.integer(beta.size),
               as.integer(n),
-              res = xix)$res
+              res = xix, PACKAGE = "geoR")$res
     attr(xix, "dim") <- c(beta.size, beta.size)
     if(length(as.vector(xix)) == 1) {
       ixix <- 1/xix
@@ -944,7 +944,7 @@ function(lambda)
               as.integer(beta.size),
               as.integer(1),
               as.integer(n),
-              res = xiy)$res
+              res = xiy, PACKAGE = "geoR")$res
     beta.hat <- as.vector(ixix %*% xiy)
     yiy <- as.double(0.0)
     yiy <- .C("bilinearform_XAY",
@@ -955,7 +955,7 @@ function(lambda)
               as.integer(1),
               as.integer(1),
               as.integer(n),
-              res = yiy)$res
+              res = yiy, PACKAGE = "geoR")$res
     ssresmat <- as.vector(yiy - crossprod(beta.hat,xiy))
     if(.temp.list$method == "ML") {
       neglik <- ((n/2) * log(2 * pi) +
@@ -1050,7 +1050,7 @@ function(lambda)
               as.integer(beta.size),
               as.integer(beta.size),
               as.integer(n),
-              res = xix)$res
+              res = xix, PACKAGE = "geoR")$res
     attr(xix, "dim") <- c(beta.size, beta.size)
     if(length(as.vector(xix)) == 1) {
       ixix <- 1/xix
@@ -1070,7 +1070,7 @@ function(lambda)
               as.integer(beta.size),
               as.integer(1),
               as.integer(n),
-              res = xiy)$res
+              res = xiy, PACKAGE = "geoR")$res
     beta.hat <- as.vector(ixix %*% xiy)
     yiy <- as.double(0.0)
     yiy <- .C("bilinearform_XAY",
@@ -1081,7 +1081,7 @@ function(lambda)
               as.integer(1),
               as.integer(1),
               as.integer(n),
-              res = yiy)$res
+              res = yiy, PACKAGE = "geoR")$res
     ssresmat <- as.vector(yiy - crossprod(beta.hat,xiy))
     if(.temp.list$method == "ML") {
       neglik <- ((n/2) * log(2 * pi) + covinf$log.det.to.half +
